==> release-1.6.tar.gz: website/docs/tutorials/index.md <==
---
title: Tutorials
redirect_from:
- "/docs/samples/"
- "/docs/samples.html"
---

This section of the Kubernetes documentation contains tutorials.
A tutorial shows how to accomplish a goal that is larger than a single
[task](/docs/tasks/). Typically a tutorial has several sections,
each of which has a sequence of steps.

* [Kubernetes Basics](/docs/tutorials/kubernetes-basics/) is an in-depth interactive tutorial that helps you understand the Kubernetes system and try out some basic Kubernetes features.

* [Online Training Course](https://www.udacity.com/course/scalable-microservices-with-kubernetes--ud615)

* [Hello Minikube](/docs/tutorials/stateless-application/hello-minikube/)

#### Stateless Applications

* [Running a Stateless Application Using a Deployment](/docs/tutorials/stateless-application/run-stateless-application-deployment/)

* [Example: PHP Guestbook application with Redis](/docs/tutorials/stateless-application/guestbook/)

* [Using a Service to Access an Application in a Cluster](/docs/tutorials/stateless-application/expose-external-ip-address-service/)

* [Exposing an External IP Address to Access an Application in a Cluster](/docs/tutorials/stateless-application/expose-external-ip-address/)

#### Stateful Applications

* [StatefulSet Basics](/docs/tutorials/stateful-application/basic-stateful-set/)

* [Running a Single-Instance Stateful Application](/docs/tutorials/stateful-application/run-stateful-application/)

* [Running a Replicated Stateful Application](/docs/tutorials/stateful-application/run-replicated-stateful-application/)

* [Example: WordPress and MySQL with Persistent Volumes](/docs/tutorials/stateful-application/mysql-wordpress-persistent-volume/)

* [Example: Deploying Cassandra with Stateful Sets](/docs/tutorials/stateful-application/cassandra/)

* [Running ZooKeeper, A CP Distributed System](/docs/tutorials/stateful-application/zookeeper/)

#### Connecting Applications

* [Connecting a Front End to a Back End Using a Service](/docs/tutorials/connecting-apps/connecting-frontend-backend/)

#### Services

* [Using SourceIP](/docs/tutorials/services/source-ip/)

### What's next

If you would like to write a tutorial, see
[Using Page Templates](/docs/home/contribute/page-templates/)
for information about the tutorial page type and the tutorial template.

==> release-1.7.tar.gz: website/docs/tutorials/index.md <==
---
title: Tutorials
---

This section of the Kubernetes documentation contains tutorials.
A tutorial shows how to accomplish a goal that is larger than a single
[task](/docs/tasks/). Typically a tutorial has several sections,
each of which has a sequence of steps.

* [Kubernetes Basics](/docs/tutorials/kubernetes-basics/) is an in-depth interactive tutorial that helps you understand the Kubernetes system and try out some basic Kubernetes features.

* [Scalable Microservices with Kubernetes (Udacity)](https://www.udacity.com/course/scalable-microservices-with-kubernetes--ud615)

* [Introduction to Kubernetes (edX)](https://www.edx.org/course/introduction-kubernetes-linuxfoundationx-lfs158x#)

* [Hello Minikube](/docs/tutorials/stateless-application/hello-minikube/)

#### Stateless Applications

* [Running a Stateless Application Using a Deployment](/docs/tutorials/stateless-application/run-stateless-application-deployment/)

* [Example: PHP Guestbook application with Redis](/docs/tutorials/stateless-application/guestbook/)

* [Using a Service to Access an Application in a Cluster](/docs/tutorials/stateless-application/expose-external-ip-address-service/)

* [Exposing an External IP Address to Access an Application in a Cluster](/docs/tutorials/stateless-application/expose-external-ip-address/)

#### Stateful Applications

* [StatefulSet Basics](/docs/tutorials/stateful-application/basic-stateful-set/)

* [Running a Single-Instance Stateful Application](/docs/tutorials/stateful-application/run-stateful-application/)

* [Running a Replicated Stateful Application](/docs/tasks/run-application/run-replicated-stateful-application/)

* [Example: WordPress and MySQL with Persistent Volumes](/docs/tutorials/stateful-application/mysql-wordpress-persistent-volume/)

* [Example: Deploying Cassandra with Stateful Sets](/docs/tutorials/stateful-application/cassandra/)

* [Running ZooKeeper, A CP Distributed System](/docs/tutorials/stateful-application/zookeeper/)

#### CI/CD Pipeline

* [Set Up a CI/CD Pipeline with Kubernetes Part 1: Overview](https://www.linux.com/blog/learn/chapter/Intro-to-Kubernetes/2017/5/set-cicd-pipeline-kubernetes-part-1-overview)

* [Set Up a CI/CD Pipeline with a Jenkins Pod in Kubernetes (Part 2)](https://www.linux.com/blog/learn/chapter/Intro-to-Kubernetes/2017/6/set-cicd-pipeline-jenkins-pod-kubernetes-part-2)

* [Run and Scale a Distributed Crossword Puzzle App with CI/CD on Kubernetes (Part 3)](https://www.linux.com/blog/learn/chapter/intro-to-kubernetes/2017/6/run-and-scale-distributed-crossword-puzzle-app-cicd-kubernetes-part-3)

* [Set Up CI/CD for a Distributed Crossword Puzzle App on Kubernetes (Part 4)](https://www.linux.com/blog/learn/chapter/intro-to-kubernetes/2017/6/set-cicd-distributed-crossword-puzzle-app-kubernetes-part-4)

#### Connecting Applications

* [Connecting a Front End to a Back End Using a Service](/docs/tutorials/connecting-apps/connecting-frontend-backend/)

#### Services

* [Using Source IP](/docs/tutorials/services/source-ip/)

### What's next

If you would like to write a tutorial, see
[Using Page Templates](/docs/home/contribute/page-templates/)
for information about the tutorial page type and the tutorial template.
